OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Annettu operaattori on virheellinen",
    "The given regular expression is invalid" : "Määritetty säännöllinen lauseke on virheellinen",
    "The given file size is invalid" : "Annettu tiedoston koko on virheellinen",
    "The given tag id is invalid" : "Annettu tag id on virheellinen",
    "The given IP range is invalid" : "Annetut IP-arvot ovat virheelliset",
    "The given IP range is not valid for IPv4" : "Annetut IP-arvot eivät käy IPv4-osoitteisiin",
    "The given IP range is not valid for IPv6" : "Annetut IP-arvot eivät käy IPv6-osoitteisiin",
    "The given time span is invalid" : "Annettu aikaväli on virheellinen",
    "The given start time is invalid" : "Annettu aloitusaika on virheellinen",
    "The given end time is invalid" : "Annettu päättymisaika on virheellinen",
    "The given group does not exist" : "Annettua ryhmää ei ole",
    "File" : "Tiedosto",
    "File created" : "Tiedosto luotu",
    "File updated" : "Tiedosto päivitetty",
    "File renamed" : "Tiedosto nimetty uudelleen",
    "File deleted" : "Tiedosto poistettu",
    "File accessed" : "Tiedostoa käytetty",
    "File copied" : "Tiedosto kopioitu",
    "Tag assigned" : "Tunniste asetettu",
    "Someone" : "Joku",
    "%s created %s" : "%s loi %s",
    "%s modified %s" : "%s muokkasi %s",
    "%s deleted %s" : "%s poisti %s",
    "%s accessed %s" : "%s käytti %s",
    "%s renamed %s" : "%s nimesi uudelleen %s",
    "%s copied %s" : "%s kopioi %s",
    "Operation #%s does not exist" : "Toimenpidettä #%s ei ole olemassa",
    "Entity %s does not exist" : "Entiteettiä %s ei ole olemassa",
    "Entity %s is invalid" : "Entiteetti %s on virheellinen",
    "No events are chosen." : "Tapahtumia ei ole valittu.",
    "Entity %s has no event %s" : "Entiteetillä %s ei ole tapahtumaa %s",
    "Operation %s does not exist" : "Toimenpidettä %s ei ole olemassa",
    "Operation %s is invalid" : "Toimenpide %s on virheellinen",
    "Check %s does not exist" : "Tarkistusta %s ei ole olemassa",
    "Check %s is invalid" : "Tarkistus %s on virheellinen",
    "Check #%s does not exist" : "Tarkistusta #%s ei ole olemassa",
    "Check %s is invalid or does not exist" : "Tarkistus %s on virheellinen tai sitä ei ole olemassa",
    "Flow" : "Kulku",
    "Nextcloud workflow engine" : "Nextcloudin työnkulkumoottori",
    "Select a file type" : "Valitse tiedostotyyppi",
    "Folder" : "Kansio",
    "Images" : "Kuvat",
    "Office documents" : "Toimisto-ohjelmistojen asiakirjat",
    "PDF documents" : "PDF-asiakirjat",
    "Custom mimetype" : "Mukautettu MIME-tyyppi",
    "Predefined URLs" : "Ennalta määritellyt URL-osoitteet",
    "Files WebDAV" : "Tiedostot WebDAV",
    "Others" : "Muut",
    "Android client" : "Android-sovellus",
    "iOS client" : "iOS-sovellus",
    "Desktop client" : "Työpöytäsovellus",
    "Thunderbird & Outlook addons" : "Thunderbird- & Outlook-lisäosat",
    "and" : "ja",
    "Cancel" : "Peruuta",
    "Delete" : "Poista",
    "Active" : "Aktiivinen",
    "Save" : "Tallenna",
    "Browse the App Store" : "Selaa Sovelluskauppaa",
    "Show less" : "Näytä vähemmän",
    "Show more" : "Näytä enemmän",
    "matches" : "täsmää",
    "does not match" : "ei täsmää",
    "is" : "on",
    "is not" : "ei ole",
    "File name" : "Tiedostonimi",
    "File MIME type" : "Tiedoston MIME-tyyppi",
    "File size (upload)" : "Tiedostokoko (lähetys)",
    "less" : "pienempi",
    "less or equals" : "pienempi tai yhtä suuri kuin",
    "greater or equals" : "suurempi tai yhtä suuri kuin",
    "greater" : "suurempi",
    "Request remote address" : "Pyynnön etäosoite",
    "matches IPv4" : "täsmää IPv4-osoitteeseen",
    "does not match IPv4" : "ei täsmää IPv4-osoitteeseen",
    "matches IPv6" : "täsmää IPv6-osoitteeseen",
    "does not match IPv6" : "ei täsmää IPv6-osoitteeseen",
    "File system tag" : "Järjestelmätunniste",
    "is tagged with" : "on merkitty tunnisteella",
    "is not tagged with" : "ei ole merkitty tunnisteella",
    "Request URL" : "Pyynnön URL-osoite",
    "Request time" : "Pyynnön aika",
    "between" : "välillä",
    "not between" : "ei välillä",
    "Request user agent" : "Pyynnön user agent",
    "User group membership" : "Käyttäjäryhmäjäsenyys",
    "is member of" : "on jäsen",
    "is not member of" : "ei ole jäsen",
    "No results" : "Ei tuloksia",
    "%s (invisible)" : "%s (näkymätön)",
    "%s (restricted)" : "%s (rajoitettu)"
},
"nplurals=2; plural=(n != 1);");
